@@ -1,6 +1,7 @@
 context("test-get_libraries")
 
 test_that("get_libraries() – all", {
+  skip_on_cran()
   expect_identical(x <- get_libraries(), c("convert", "ffmpeg"))
 })
 
@@ -10,7 +11,4 @@ test_that("get_libraries() - options", {
    
   expect_is(getOption("moveVis.convert_avail"), "logical")
   expect_is(getOption("moveVis.ffmpeg_avail"), "logical")
-  
-  expect_true(getOption("moveVis.convert_avail"))
-  expect_true(getOption("moveVis.ffmpeg_avail"))
 })
\ No newline at end of file
